@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.46 2004/05/17 17:41:44 padraigo Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.56 2005/01/31 17:32:18 richb Exp $
  *
- *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,15 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <assert.h>
 #include "calctool.h"
+#include <gdk/gdkkeysyms.h>
 #include "extern.h"
+#include "mpmath.h"
 
 static char *make_eng_sci(int *, int);
 static char *make_fixed(int *, int, int);
 
-
 /* Add in the thousand separators characters if required and if we are
  * currently in the decimal numeric base, use the "right" radix character.
  */
@@ -38,53 +40,54 @@ localize_number(char *dest, const char *src)
     char tnum[MAX_LOCALIZED], *dstp;
 
     if (!v->error && v->show_tsep && v->base == DEC) {
-	const char *radixp, *srcp;
-	int n, i;
-	size_t tsep_len;
+        const char *radixp, *srcp;
+        int n, i;
+        size_t tsep_len;
 
-	/* Process the fractional part (if any). */
-	srcp = src + strlen(src) - 1;
-	dstp = tnum;
-	if ((radixp = strchr(src, '.')) != NULL) {
+        /* Process the fractional part (if any). */
+        srcp = src + strlen(src) - 1;
+        dstp = tnum;
+        if ((radixp = strchr(src, '.')) != NULL) {
             while (srcp != radixp) {
-    		*dstp++ = *srcp--;
+                *dstp++ = *srcp--;
             }
-	    *dstp++ = *srcp--;
-    	}
+            *dstp++ = *srcp--;
+        }
 
-    	/* Process the integer part, add in thousand separators. */
-	tsep_len = strlen(v->tsep);
-    	n = 0;
-    	while (srcp >= src) {
+        /* Process the integer part, add in thousand separators. */
+        tsep_len = strlen(v->tsep);
+        n = 0;
+        while (srcp >= src) {
             *dstp++ = *srcp--;
             n++;
             if (n == 3 && srcp >= src && *srcp != '-') {
-	        for (i = tsep_len - 1; i >= 0; i--)
-		    *dstp++ = v->tsep[i];
-		n = 0;
+                for (i = tsep_len - 1; i >= 0; i--) {
+                    *dstp++ = v->tsep[i];
+                }
+                n = 0;
             }
-	}
-	*dstp++ = '\0';
+        }
+        *dstp++ = '\0';
 
-	/* Move from scratch pad to fnum, reversing the character order. */
-	srcp = tnum + strlen(tnum) - 1;
-	dstp = dest;
-	while (srcp >= tnum) {
+        /* Move from scratch pad to fnum, reversing the character order. */
+        srcp = tnum + strlen(tnum) - 1;
+        dstp = dest;
+        while (srcp >= tnum) {
             *dstp++ = *srcp--;
-	}
-	*dstp++ = '\0';
+        }
+        *dstp++ = '\0';
     } else {
-	STRCPY(dest, src);
+        STRCPY(dest, src);
     }
     dstp = strchr(dest, '.');
     if (dstp != NULL) {
-	size_t radix_len;
+        size_t radix_len;
 
-	radix_len = strlen(v->radix);
-	if (radix_len != 1) {
-	    memmove(dstp + radix_len, dstp + 1, strlen (dstp + 1) + 1);
-	}
-	MEMCPY(dstp, v->radix, radix_len);
+        radix_len = strlen(v->radix);
+        if (radix_len != 1) {
+            memmove(dstp + radix_len, dstp + 1, strlen (dstp + 1) + 1);
+        }
+        MEMCPY(dstp, v->radix, radix_len);
     }
 }
 
@@ -127,23 +130,17 @@ clear_display(int initialise)
 }
 
 
+/* FIXME: not a right location for this function. */
+
 struct button *
 copy_button_info(struct button *old)
 {
     struct button *new;
 
+    int len = sizeof(struct button);
     new = malloc(sizeof(struct button));
-
-/* Note that copies of the strings aren't done here as they aren't needed. */
-
-    new->str = old->str;
-    new->hstr = old->hstr;
-    new->astr = old->astr;
-    new->mods[0] = old->mods[0];
-    new->value[0] = old->value[0];
-    new->func_char = old->func_char;
-    new->mtype = old->mtype;
-    new->func = old->func;
+    assert(new);
+    memcpy(new, old, len);
 
     return(new);
 }
@@ -152,15 +149,23 @@ copy_button_info(struct button *old)
 void
 initialise()
 {
-    int i;
+    /* TODO: perhaps this function should be renamed to reset. */
 
+    int i;
+  
     v->error         = 0;           /* Currently no display error. */
     v->cur_op        = '?';         /* No arithmetic operator defined yet. */
     v->old_cal_value = '?';
     v->pending       = 0;
     i = 0;
     mpcim(&i, v->MPresult);         /* No previous result yet. */
+    mpcim(&i, v->MPdisp_val);         
     mpcim(&i, v->MPlast_input);
+  
+    v->new_input = 1;               /* Value zero is on calculator display */
+
+    free(v->expression);
+    v->expression = NULL;
 }
 
 
@@ -188,7 +193,7 @@ make_fixed(int *MPnumber, int base, int cmax)
     mpcim(&basevals[base], MP1base);
 
     mppwr(MP1base, &v->accuracy, MP1);
-    SPRINTF(half, "0.5"); /* FIXME: string constant if MPstr_to_num can get it */
+    SPRINTF(half, "0.5"); /* FIXME: string const. if MPstr_to_num can get it */
     MPstr_to_num(half, DEC, MP2);
     mpdiv(MP2, MP1, MP1);
     mpadd(MPval, MP1, MPval);
@@ -209,7 +214,7 @@ make_fixed(int *MPnumber, int base, int cmax)
 
     while (ndig-- > 0) {
         if (ddig-- == 0) {
-	    *optr++ = '.';
+            *optr++ = '.';
         }
         mpmul(MPval, MP1base, MPval);
         mpcmi(MPval, &dval);
@@ -231,9 +236,9 @@ make_fixed(int *MPnumber, int base, int cmax)
         while (*optr == '0') {
             optr--;
         }
-	if (optr < v->fnum || *optr != '.') {
-	    optr++;
-	}
+    if (optr < v->fnum || *optr != '.') {
+        optr++;
+    }
         *optr = '\0';
     }
 
@@ -311,7 +316,7 @@ make_eng_sci(int *MPnumber, int base)
     n = 0;
     mpcim(&n, MP1);
     if (!mpeq(MPmant, MP1)) {
-        while (mpge(MPmant, MP10base)) {
+        while (!eng && mpge(MPmant, MP10base)) {
             exp += 10;
             mpmul(MPmant, MPatmp, MPmant);
         }
@@ -322,7 +327,7 @@ make_eng_sci(int *MPnumber, int base)
             mpdiv(MPmant, MP1base, MPmant);
         }
  
-        while (mplt(MPmant, MPatmp)) {
+        while (!eng && mplt(MPmant, MPatmp)) {
             exp -= 10;
             mpmul(MPmant, MP10base, MPmant);
         }
@@ -408,7 +413,7 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
             mpcim(&inum, MP2);
             mpdiv(MP2, MP1, MP1);
             mpadd(MPval, MP1, MPval);
-	    optr++;
+        optr++;
         }
     }
 
@@ -452,7 +457,7 @@ paren_disp(char c)
  */
 
     n = strlen(v->display);
-    if (c == -1) {         /* Is it a Delete character? */
+    if (c == -1 || c == 127) {         /* Is it a Delete character? */
         v->noparens = v->pending = v->opsptr = v->numsptr = 0;
         v->cur_op = '?';
         i = 0;
@@ -474,7 +479,7 @@ paren_disp(char c)
                 show_display(v->MPdisp_val);
                 return;
             }
-        }
+        } else if (v->display[n-1] == ')') v->noparens++;
         v->display[n-1] = '\0';
 
     } else if (c == '(') {
@@ -565,3 +570,42 @@ show_display(int *MPval)
         set_display(v->display, FALSE);
     }
 }
+
+void
+refresh_display()
+{
+  /* In arithmetic precedence mode this
+     routine should be called to redraw display.
+  */
+
+  char localized[MAX_LOCALIZED];
+
+  switch (v->syntax) {
+  case npa:
+    show_display(v->MPdisp_val);
+    break;
+    
+  case exprs:
+    if (v->expression &&
+	strlen(v->expression)) {
+      char *e = gc_strdup(v->expression);
+      char *ans = make_number(v->e.ans, v->base, TRUE, FALSE);
+      localize_number(localized, ans);
+      
+      str_replace(&e, "Ans", localized);
+      //set_display(e, FALSE);
+      write_display(e);
+      free(e);
+    } else {
+      /* set_display("", FALSE); */
+      int MP1[MP_SIZE];
+      do_zero(MP1);
+      show_display(MP1);
+    }
+    
+    break;
+    
+  default:
+    assert(0);
+  }
+}
