@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.h,v 1.4 2004/07/19 17:41:04 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.h,v 1.6 2005/01/31 17:32:18 richb Exp $
  *
- *  Copyright (C) 2004 Sami Pietila
+ *  Copyright (C) 2004-2005 Sami Pietila
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,10 +25,7 @@
 #include "calctool.h"
 #include "extern.h"
 
-int do_trigfunc(int s[MP_SIZE], int t[MP_SIZE]);
-
 void do_factorial(int *, int *);
-void do_immedfunc(int s[MP_SIZE], int t[MP_SIZE]);
-void do_portionfunc(int num[MP_SIZE]);
+void exp_append(char *text);
 
 #endif /*FUNCTIONS_H*/
