@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.152 2005/01/21 21:26:32 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.155 2005/02/03 17:57:22 richb Exp $
  *
- *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
+#include <gnome.h>
 #include <gconf/gconf-client.h>
 #include "ce_parser.h"
 
@@ -158,7 +159,7 @@ static gboolean dismiss_spframe(GtkWidget *, GdkEvent *, gpointer);
 static gboolean kframe_key_press_cb(GtkWidget *, GdkEventKey *, gpointer);
 static gboolean spframe_key_cb(GtkWidget *, GdkEventKey *, gpointer);
 
-static void about_cb(GtkAction *action);
+static void about_cb(GtkAction *action, gpointer);
 static void add_cf_column(GtkTreeView *, gchar *, gint, gboolean);
 static void aframe_cancel_cb(GtkButton *, gpointer);
 static void aframe_ok_cb(GtkButton *, gpointer);
@@ -183,11 +184,14 @@ static void put_constant(int, char *, char *);
 static void put_function(int, char *, char *);
 static void quit_cb(GtkWidget *, gpointer);
 static void reset_mode_values(enum mode_type);
+static void set_accuracy_toggle(int val);
 static void set_button_state(GtkWidget *, int);
 static void set_gcalctool_icon(void);
+static void set_item(enum item_type itemtype, int val);
 static void set_memory_toggle(int);
 static void set_show_tsep_toggle(int);
 static void set_show_zeroes_toggle(int);
+static void show_ascii_frame();
 static void show_precision_frame();
 static void spframe_cancel_cb(GtkButton *, gpointer);
 static void spframe_ok_cb(GtkButton *, gpointer);
@@ -223,7 +227,7 @@ static GtkActionEntry entries[] = {
 
     { "Contents", GTK_STOCK_HELP, N_("_Contents"), "F1",
       N_("Show help contents"), G_CALLBACK(mb_proc) },
-    { "About", GNOME_STOCK_ABOUT, N_("_About"), NULL,
+    { "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
       N_("Show the About Gcalctool dialog"), G_CALLBACK(about_cb) },
 
     { "LSPlaces1",  NULL, N_("1 place"),   NULL, 
@@ -485,11 +489,9 @@ update_statusbar(gchar *text, const gchar *imagename)
 
 /*ARGSUSED*/
 static void
-about_cb(GtkAction *action)
+about_cb(GtkAction *action, gpointer date)
 {
-    static GtkWidget *about = NULL;
-
-    if (about == NULL) {
+    
         const gchar *authors[] = {
             "Rich Burridge <rich.burridge@sun.com>",
             "Sami Pietila <sampie@ariana-dsl.utu.fi>",
@@ -501,21 +503,16 @@ about_cb(GtkAction *action)
         };
         const gchar *translator_credits = _("translator_credits");
 
-        about = gnome_about_new(_("Gcalctool"),
-                       VERSION,
-                       "(C) 2004 the Free Software Foundation",
-                       _("Calculator with financial and scientific modes."),
-                       authors,
-                       documenters,
-                       strcmp(translator_credits, "translator_credits") != 0 ? 
-                              translator_credits : NULL,
-                       X->icon);
-
-        g_signal_connect(G_OBJECT(about), "destroy",
-                         G_CALLBACK(gtk_widget_destroyed), &about);
-        gtk_window_set_icon(GTK_WINDOW(about), X->icon);    
-    }
-    gtk_window_present(GTK_WINDOW(about));
+        gtk_show_about_dialog(GTK_WINDOW (X->kframe),
+        					"name",_("Gcalctool"),
+        					"version", VERSION,
+        					"copyright", "(C) 2004 the Free Software Foundation",
+        					"comments", _("Calculator with financial and scientific modes."),
+        					"authors", authors,
+        					"documenters", documenters,
+        					"translator-credits", strcmp(translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+        					"logo", X->icon);
+        					
 }
 
 
@@ -1230,18 +1227,15 @@ create_kframe()
         gtk_window_set_focus(GTK_WINDOW(X->kframe), GTK_WIDGET(BUT_CLR_ADV));
     }
 
-    X->khbox = gtk_hbox_new(FALSE, 0);
-    gtk_widget_show(X->khbox);
-    gtk_container_add(GTK_CONTAINER(X->kvbox), X->khbox);
     X->statusbar = gtk_statusbar_new();
     gtk_widget_show(X->statusbar);
-    gtk_box_pack_start(GTK_BOX(X->khbox), X->statusbar, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(X->kvbox), X->statusbar, FALSE, FALSE, 0);
     gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(X->statusbar), FALSE);
 
     X->status_image = gtk_image_new_from_stock("", 
 					       GTK_ICON_SIZE_BUTTON);
     gtk_widget_show(X->status_image);
-    gtk_box_pack_start(GTK_BOX(X->khbox), X->status_image, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(X->statusbar), X->status_image, FALSE, TRUE, 0);
     g_signal_connect(G_OBJECT(X->kframe), "key_press_event",
                      G_CALLBACK(kframe_key_press_cb), NULL);
 
@@ -2526,7 +2520,6 @@ set_display(char *str, int minimize_changes)
 void
 write_display(char *str)
 {
-    char localized[MAX_LOCALIZED];
     gchar *text;
     GtkTextBuffer *buffer;
     GtkTextIter start, end;
