@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/mp.c,v 1.13 2004/07/27 22:06:31 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/mp.c,v 1.14 2004/11/03 22:50:20 richb Exp $
  *
- *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -3346,10 +3346,7 @@ mppwr2(int *x, int *y, int *z)
     else goto L70;
 
 L10:
-    if (v->MPerrors) {
-        FPRINTF(stderr, "*** X NEGATIVE IN CALL TO MPPWR2 ***\n");
-    }
-
+    show_error(_("Negative X and non-integer Y not supported"));
     goto L50;
 
 /* HERE X IS ZERO, RETURN ZERO IF Y POSITIVE, OTHERWISE ERROR */
